@@ -1,12 +1,11 @@
 """Data models for Spark API"""
 
-from typing import Optional, Dict, Any, List
-from datetime import datetime
 from enum import Enum
 
 
 class WorkflowType(str, Enum):
     """Workflow types supported by Spark"""
+
     AGENT = "hive_agent"
     TEAM = "hive_team"
     WORKFLOW = "hive_workflow"
@@ -15,6 +14,7 @@ class WorkflowType(str, Enum):
 
 class TaskStatus(str, Enum):
     """Task execution status"""
+
     PENDING = "pending"
     RUNNING = "running"
     COMPLETED = "completed"
@@ -23,12 +23,14 @@ class TaskStatus(str, Enum):
 
 class ScheduleType(str, Enum):
     """Schedule type for workflow execution"""
+
     INTERVAL = "interval"
     CRON = "cron"
 
 
 class ScheduleStatus(str, Enum):
     """Schedule status"""
+
     ACTIVE = "active"
     INACTIVE = "inactive"
     PAUSED = "paused"
@@ -36,6 +38,7 @@ class ScheduleStatus(str, Enum):
 
 class SourceType(str, Enum):
     """Workflow source types"""
+
     AUTOMAGIK_AGENTS = "automagik-agents"
     AUTOMAGIK_HIVE = "automagik-hive"
-    LANGFLOW = "langflow"
\ No newline at end of file
+    LANGFLOW = "langflow"
